<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.0">
<context>
    <name>HelloWorld</name>
    <message>
        <source>Hello World:</source>
        <translation>Olá mundo:</translation>
    </message>
    <message>
        <source>Display Text Configuration</source>
        <translation>Configuração</translation>
    </message>
    <message>
        <source>Edit HTML</source>
        <translation>Editar HTML</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Display simple text. A debugging/sample widget.</source>
        <translation>Mostrar texto. Um widget de depuração/exemplo.</translation>
    </message>
</context>
</TS>